@@ -269,6 +269,12 @@ class GasOil(object):
                 swlfrominput,
             )
             logger.warning("         Do not trust the result near the endpoint.")
+
+        if 0 < swlfrominput - self.swl < epsilon:
+            # Perturb max sg in incoming dataframe when we are this close,
+            # or we will get into floating trouble when interpolating.
+            dframe.loc[dframe[sgcolname].idxmax(), sgcolname] += swlfrominput - self.swl
+
         if krgcolname in dframe:
             if not (dframe[krgcolname].diff().dropna() > -epsilon).all():
                 raise ValueError("Incoming krg not increasing")
@@ -395,7 +401,7 @@ class GasOil(object):
         self.table.loc[self.table["krog"] > kroend, "krog"] = kroend
 
     def add_corey_gas(self, ng=2, krgend=1, krgmax=None):
-        """ Add krg data through the Corey parametrization
+        """Add krg data through the Corey parametrization
 
         A column called 'krg' will be added. If it exists, it will
         be replaced.
@@ -448,7 +454,10 @@ class GasOil(object):
 
         self.set_endpoints_linearpart_krog(kroend)
 
-        self.krogcomment = "-- Corey krog, nog=%g, kroend=%g\n" % (nog, kroend,)
+        self.krogcomment = "-- Corey krog, nog=%g, kroend=%g\n" % (
+            nog,
+            kroend,
+        )
 
     def add_LET_gas(self, l=2, e=2, t=2, krgend=1, krgmax=None):
         """
