@@ -6,7 +6,6 @@ from __future__ import division
 from __future__ import print_function
 
 import os
-import logging
 
 import six
 
@@ -18,6 +17,7 @@ import pytest
 from pyscal import (
     WaterOil,
     GasOil,
+    GasWater,
     WaterOilGas,
     PyscalFactory,
     factory,
@@ -29,9 +29,6 @@ from common import sat_table_str_ok, check_table
 
 def test_factory_wateroil():
     """Test that we can create curves from dictionaries of parameters"""
-
-    logging.getLogger().setLevel("INFO")
-
     factory = PyscalFactory()
 
     # Factory refuses to create incomplete defaulted objects.
@@ -85,6 +82,7 @@ def test_factory_wateroil():
     sat_table_str_ok(wateroil.SWOF())
     sat_table_str_ok(wateroil.SWFN())
 
+    # Mixing Corey and LET
     wateroil = factory.create_water_oil(dict(Lw=2, Ew=2, Tw=2, krwend=1, now=4))
     assert isinstance(wateroil, WaterOil)
     assert "krw" in wateroil.table
@@ -170,9 +168,6 @@ def test_ambiguity():
 
 def test_factory_gasoil():
     """Test that we can create curves from dictionaries of parameters"""
-
-    logging.getLogger().setLevel("INFO")
-
     factory = PyscalFactory()
 
     with pytest.raises(TypeError):
@@ -218,10 +213,53 @@ def test_factory_gasoil():
     assert "LET krog" in sgof
 
 
+def test_factory_gaswater():
+    """Test that we can create gas-water curves from dictionaries of parameters"""
+    factory = PyscalFactory()
+
+    with pytest.raises(TypeError):
+        factory.create_gas_water(swirr=0.01)  # noqa
+
+    gaswater = factory.create_gas_water(
+        dict(swirr=0.01, swl=0.03, sgrw=0.1, sgcr=0.15, tag="gassy sand", ng=2, nw=2)
+    )
+
+    assert isinstance(gaswater, GasWater)
+
+    assert gaswater.swirr == 0.01
+    assert gaswater.swl == 0.03
+    assert gaswater.sgrw == 0.1
+    assert gaswater.sgcr == 0.15
+    assert gaswater.tag == "gassy sand"
+
+    sgfn = gaswater.SGFN()
+    swfn = gaswater.SWFN()
+    sat_table_str_ok(sgfn)
+    sat_table_str_ok(swfn)
+    check_table(gaswater.wateroil.table)
+    check_table(gaswater.gasoil.table)
+
+    assert "sgrw=0.1" in swfn
+    assert "swirr=0.01" in sgfn
+    assert "swirr=0.01" in swfn
+    assert "sgrw=0.1" in swfn
+    assert "sgcr=0.15" in sgfn
+    assert "nw=2" in swfn
+    assert "ng=2" in sgfn
+    assert "gassy sand" in sgfn
+
+    gaswater = factory.create_gas_water(dict(lg=1, eg=1, tg=1, nw=3))
+
+    sgfn = gaswater.SGFN()
+    swfn = gaswater.SWFN()
+    sat_table_str_ok(sgfn)
+    sat_table_str_ok(swfn)
+    check_table(gaswater.wateroil.table)
+    check_table(gaswater.gasoil.table)
+
+
 def test_factory_wateroilgas():
     """Test creating discrete cases of WaterOilGas from factory"""
-    logging.getLogger().setLevel("INFO")
-
     factory = PyscalFactory()
 
     wog = factory.create_water_oil_gas(dict(nw=2, now=3, ng=1, nog=2.5))
@@ -248,15 +286,35 @@ def test_factory_wateroilgas():
     assert "Corey krow" in swof
 
     # Mangling data
-    with pytest.raises(ValueError):
-        factory.create_water_oil_gas(dict(nw=2, now=3, ng=1))
+    wateroil = factory.create_water_oil_gas(dict(nw=2, now=3, ng=1))
+    assert wateroil.gasoil is None
+
+
+def test_factory_wateroilgas_deprecated_krowgend(caplog):
+    """Some users will use deprecated  krowend krogend,
+    these values should be translated to kroend"""
+    wog = PyscalFactory.create_water_oil_gas(
+        dict(nw=2, now=3, ng=1, nog=2.5, krowend=0.6, krogend=0.7)
+    )
+    assert "deprecated" in caplog.text
+    swof = wog.SWOF()
+    assert "kroend=0.6" in swof
+    sgof = wog.SGOF()
+    assert "kroend=0.7" in sgof
+    assert not wog.threephaseconsistency()
+    sat_table_str_ok(swof)  # sgof code works for swof also currently
+    sat_table_str_ok(sgof)
+    assert "Corey krg" in sgof
+    assert "Corey krog" in sgof
+    assert "Corey krw" in swof
+    assert "Corey krow" in swof
 
 
 def test_factory_wateroilgas_wo():
     """Test making only wateroil through the wateroilgas factory"""
     factory = PyscalFactory()
     wog = factory.create_water_oil_gas(
-        dict(nw=2, now=3, krowend=0.5, sorw=0.04, swcr=0.1)
+        dict(nw=2, now=3, kroend=0.5, sorw=0.04, swcr=0.1)
     )
     swof = wog.SWOF()
     assert "Corey krw" in swof
@@ -406,7 +464,7 @@ def test_create_lists():
 
 
 def test_scalrecommendation():
-    """Testing making SCAL rec from dict of dict"""
+    """Testing making SCAL rec from dict of dict."""
 
     factory = PyscalFactory()
 
@@ -417,7 +475,13 @@ def test_scalrecommendation():
     }
     scal = factory.create_scal_recommendation(scal_input)
     # (not supported yet to make WaterOil only..)
-    scal.interpolate(-0.5).SWOF()
+    interp = scal.interpolate(-0.5)
+    sat_table_str_ok(interp.SWOF())
+    sat_table_str_ok(interp.SGOF())
+    sat_table_str_ok(interp.SLGOF())
+    sat_table_str_ok(interp.SOF3())
+    check_table(interp.wateroil.table)
+    check_table(interp.gasoil.table)
 
     incomplete1 = scal_input.copy()
     del incomplete1["BASE"]
@@ -431,11 +495,26 @@ def test_scalrecommendation():
     assert gasoil.low.wateroil is None
     assert gasoil.base.wateroil is not None
     assert gasoil.high.wateroil is not None
-    interp = scal.interpolate(-0.5)
-    sat_table_str_ok(interp.SWOF())
-    sat_table_str_ok(interp.SGOF())
-    sat_table_str_ok(interp.SLGOF())
-    sat_table_str_ok(interp.SOF3())
+    # SCALrecommendation of gasoil only works as long as you
+    # don't try to ask for water data:
+    assert "SGFN" in gasoil.interpolate(-0.4).SGFN()
+    assert "SWOF" not in gasoil.interpolate(-0.2).SWOF()
+
+
+def test_scalrecommendation_gaswater():
+    """Testing making SCAL rec from dict of dict for gaswater input"""
+
+    factory = PyscalFactory()
+
+    scal_input = {
+        "low": {"nw": 2, "ng": 1},
+        "BASE": {"nw": 3, "ng": 1},
+        "high": {"nw": 4, "ng": 1},
+    }
+    scal = factory.create_scal_recommendation(scal_input, h=0.2)
+    interp = scal.interpolate(-0.5, h=0.2)
+    sat_table_str_ok(interp.SWFN())
+    sat_table_str_ok(interp.SGFN())
     check_table(interp.wateroil.table)
     check_table(interp.gasoil.table)
 
@@ -460,6 +539,48 @@ def test_xls_scalrecommendation():
         scalrec.interpolate(+0.5)
 
 
+def test_no_gasoil():
+    """The command client does not support two-phase gas-oil, because
+    that is most likely an sign of a user input error.
+    (misspelled other columns f.ex).
+
+    Make sure we fail in that case."""
+    dframe = pd.DataFrame(columns=["SATNUM", "NOW", "NG"], data=[[1, 2, 2]])
+    with pytest.raises(ValueError):
+        PyscalFactory.load_relperm_df(dframe)
+
+
+def test_check_deprecated_krowgend(caplog):
+    """Up until pyscal 0.5.x, krogend and krowend were parameters
+    to the oil curve parametrization for WaterOil and GasOil. From
+    pyscal 0.6.0, krogend and krowend are merged to kroend.
+    """
+    wateroil = PyscalFactory.create_water_oil(dict(swl=0.1, nw=2, now=2, krowend=0.4))
+    assert "krowend" in caplog.text
+    assert "deprecated" in caplog.text
+    assert wateroil.table["krow"].max() == 0.4
+
+    gasoil = PyscalFactory.create_gas_oil(dict(swl=0.1, ng=2, nog=2, krogend=0.4))
+    assert "krogend" in caplog.text
+    assert "deprecated" in caplog.text
+    assert gasoil.table["krog"].max() == 0.4
+
+
+def test_check_deprecated_kromax(caplog):
+    """Up until pyscal 0.5.x, kromax was a parameter to the oil
+    curve parametrization for WaterOil and GasOil, and kro was
+    linear between swl and swcr. From pyscal 0.6, that linear
+    segment is gone, and kromax is not needed as a parameter,
+    only krowend/krogend is used.
+
+    If kromax is encountered in input data, we should warn
+    it is ignored.
+    """
+    PyscalFactory.create_water_oil(dict(swl=0.1, nw=2, now=2, kroend=0.4, kromax=0.5))
+    assert "kromax" in caplog.text
+    assert "deprecated" in caplog.text
+
+
 def parse_gensatfuncline(conf_line):
     """Utility function that emulates how gensatfunc could parse
     its configuration lines in a pyscalfactory compatible fashion
@@ -551,28 +672,50 @@ def test_sufficient_params():
 
     assert factory.sufficient_gas_oil_params({"ng": 0, "nog": 0})
     # If it looks like the user meant to create GasOil, but only provided
-    # data for krg, then we error hard. If the user did not provide
+    # data for krg, then might error hard. If the user did not provide
     # any data for GasOil, then the code returns False
     with pytest.raises(ValueError):
-        factory.sufficient_gas_oil_params({"ng": 0})
+        factory.sufficient_gas_oil_params({"ng": 0}, failhard=True)
+    assert not factory.sufficient_gas_oil_params({"ng": 0}, failhard=False)
     assert not factory.sufficient_gas_oil_params(dict())
     with pytest.raises(ValueError):
-        factory.sufficient_gas_oil_params({"lg": 0})
+        factory.sufficient_gas_oil_params({"lg": 0}, failhard=True)
+    assert not factory.sufficient_gas_oil_params({"lg": 0}, failhard=False)
     assert factory.sufficient_gas_oil_params(
         {"lg": 0, "eg": 0, "Tg": 0, "log": 0, "eog": 0, "tog": 0}
     )
 
     assert factory.sufficient_water_oil_params({"nw": 0, "now": 0})
     with pytest.raises(ValueError):
-        factory.sufficient_water_oil_params({"nw": 0})
+        factory.sufficient_water_oil_params({"nw": 0}, failhard=True)
     assert not factory.sufficient_water_oil_params(dict())
     with pytest.raises(ValueError):
-        factory.sufficient_water_oil_params({"lw": 0})
+        factory.sufficient_water_oil_params({"lw": 0}, failhard=True)
     assert factory.sufficient_water_oil_params(
         {"lw": 0, "ew": 0, "Tw": 0, "low": 0, "eow": 0, "tow": 0}
     )
 
 
+def test_sufficient_params_gaswater():
+    """Test that we can detect sufficient parameters
+    for gas-water only"""
+    assert factory.sufficient_gas_water_params({"nw": 0, "ng": 0})
+    assert not factory.sufficient_gas_water_params({"nw": 0, "nog": 0})
+    assert factory.sufficient_gas_water_params(dict(lw=0, ew=0, tw=0, lg=0, eg=0, tg=0))
+    assert not factory.sufficient_gas_water_params(dict(lw=0))
+    assert not factory.sufficient_gas_water_params(dict(lw=0, lg=0))
+    assert not factory.sufficient_gas_water_params(dict(lw=0, lg=0))
+
+    with pytest.raises(ValueError):
+        factory.sufficient_gas_water_params(dict(lw=0), failhard=True)
+    with pytest.raises(ValueError):
+        factory.sufficient_gas_water_params({"nw": 3}, failhard=True)
+
+    assert factory.sufficient_gas_water_params(dict(lw=0, ew=0, tw=0, ng=0))
+    assert factory.sufficient_gas_water_params(dict(lg=0, eg=0, tg=0, nw=0))
+    assert not factory.sufficient_gas_water_params(dict(lg=0, eg=0, tg=0, ng=0))
+
+
 def test_case_aliasing():
     """Test that we can use aliases for the CASE column
     in SCAL recommendations"""
@@ -581,11 +724,22 @@ def test_case_aliasing():
         data=[
             [1, "pess", 2, 2, 1, 1],
             [1, "base", 3, 1, 1, 1],
-            [1, "optIMIstiC", 3, 1, 1, 1],
+            [1, "opt", 3, 1, 1, 1],
         ],
     )
     relperm_data = PyscalFactory.load_relperm_df(dframe)
     PyscalFactory.create_scal_recommendation_list(relperm_data, h=0.2).interpolate(-0.4)
+    dframe = pd.DataFrame(
+        columns=["SATNUM", "CASE", "Nw", "Now", "Ng", "Nog"],
+        data=[
+            [1, "pessimistic", 2, 2, 1, 1],
+            [1, "base", 3, 1, 1, 1],
+            [1, "optiMISTIc", 3, 1, 1, 1],
+        ],
+    )
+    relperm_data = PyscalFactory.load_relperm_df(dframe)
+    PyscalFactory.create_scal_recommendation_list(relperm_data, h=0.2).interpolate(-0.4)
+
     with pytest.raises(ValueError):
         PyscalFactory.load_relperm_df(
             pd.DataFrame(
