@@ -12,7 +12,7 @@ import pytest
 from hypothesis import given, settings
 import hypothesis.strategies as st
 
-from pyscal import WaterOil, GasOil
+from pyscal import WaterOil, GasOil, WaterOilGas
 
 from common import check_table, float_df_checker
 
@@ -65,7 +65,7 @@ def test_go_fromtable_simple():
 
 def test_wo_fromtable_multiindex():
     """Test that we accept multiindex dataframes,
-        (but a warning will be issued)"""
+    (but a warning will be issued)"""
     # Test an example dataframe that easily gets sent in from ecl2df.satfunc:
     df1 = pd.DataFrame(
         columns=["KEYWORD", "SATNUM", "SW", "KRW", "KROW", "PC"],
@@ -186,6 +186,24 @@ def test_wo_singlecolumns():
     assert wateroil.table["pc"].sum() == 0
 
 
+def test_ieee_754():
+    wateroilgas = WaterOilGas(swl=0.18)
+    # For this particular swl value, we get:
+    # wateroilgas.gasoil.table.sg.max()
+    # Out[18]: 0.8200000000000001  # = (1 - 0.18)
+
+    # Can we then interpolate from a table that goes up to 0.82?
+    sgof = pd.DataFrame(
+        columns=["Sg", "krg", "krog", "pcog"], data=[[0, 0, 1, 0], [0.82, 1, 0, 0]]
+    )
+    # Note, replacing 0.82 in the table above with 1-0.18 *is not the same*
+    wateroilgas.gasoil.add_fromtable(sgof)
+    assert wateroilgas.gasoil.table["krg"].max() == 1.0
+    assert wateroilgas.gasoil.table["krog"].min() == 0.0
+    assert wateroilgas.gasoil.table["pc"].min() == 0.0
+    assert wateroilgas.gasoil.table["pc"].max() == 0.0
+
+
 def test_wo_invalidcurves():
     """Test what happens when we give in invalid data"""
     # Sw data not ordered:
