@@ -4,10 +4,12 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+import pandas as pd
+
 from hypothesis import given, settings
 import hypothesis.strategies as st
 
-from pyscal import SCALrecommendation, PyscalFactory
+from pyscal import SCALrecommendation, PyscalFactory, GasWater, WaterOilGas
 from pyscal.factory import slicedict
 
 from common import sat_table_str_ok, check_table
@@ -37,8 +39,7 @@ LOW_SAMPLE_LET = {
     "sgcr": 0.15,
     "krgend": 0.9,
     "krgmax": 1,
-    "krowend": 1,
-    "krogend": 1,
+    "kroend": 1,
     "tag": "SATNUM X",
 }
 # Example SCAL recommendation, base case
@@ -63,8 +64,7 @@ BASE_SAMPLE_LET = {
     "sorg": 0.1,
     "sgcr": 0.10,
     "krgend": 0.97,
-    "krowend": 1,
-    "krogend": 1,
+    "kroend": 1,
     "tag": "SATNUM X",
 }
 # Example SCAL recommendation, high case
@@ -89,8 +89,7 @@ HIGH_SAMPLE_LET = {
     "sorg": 0.05,
     "sgcr": 0.0,
     "krgend": 1,
-    "krowend": 1,
-    "krogend": 1,
+    "kroend": 1,
     "tag": "SATNUM X",
 }
 
@@ -108,6 +107,7 @@ def test_interpolation_deprecated(param_wo, param_go):
     )
 
     rec.add_simple_J()  # Add default pc curve
+    assert rec.type == WaterOilGas
     try:
         interpolant = rec.interpolate(param_wo, param_go, h=0.1)
     except AssertionError:
@@ -121,9 +121,36 @@ def test_interpolation_deprecated(param_wo, param_go):
     assert len(interpolant.wateroil.SWFN()) > 100
     assert len(interpolant.SOF3()) > 100
     assert len(interpolant.wateroil.SWOF()) > 100
+    if not interpolant.threephaseconsistency():
+        print(interpolant.wateroil.SWOF())
+        print(interpolant.gasoil.SGOF())
     assert interpolant.threephaseconsistency()
 
 
+def test_deprecated_kroend():
+    """Testing that the deprecated scalrecommendation can take
+    both kroend and krogend/krowend"""
+
+    low_krowend = dict(LOW_SAMPLE_LET)
+    low_krowend["krowend"] = low_krowend["kroend"]
+    del low_krowend["kroend"]
+
+    base_krowend = dict(BASE_SAMPLE_LET)
+    base_krowend["krowend"] = base_krowend["kroend"]
+    del base_krowend["kroend"]
+
+    high_krowend = dict(HIGH_SAMPLE_LET)
+    high_krowend["krowend"] = high_krowend["kroend"]
+    del high_krowend["kroend"]
+
+    rec = SCALrecommendation(low_krowend, base_krowend, high_krowend, "foo", h=0.1)
+
+    rec.add_simple_J()  # Add default pc curve
+    interpolant = rec.interpolate(0.1, 0, h=0.1)
+    check_table(interpolant.wateroil.table)
+    print(interpolant.SWOF())
+
+
 def test_make_scalrecommendation():
     """Test that we can make scal recommendation objects
     from three WaterOilGas objects"""
@@ -171,7 +198,7 @@ def test_make_scalrecommendation_wo():
         "Lo",
         "Eo",
         "To",
-        "krowend",
+        "kroend",
     ]
 
     low_let_wo = slicedict(LOW_SAMPLE_LET, wo_param_names)
@@ -210,7 +237,7 @@ def test_make_scalrecommendation_go():
         "Log",
         "Eog",
         "Tog",
-        "krogend",
+        "kroend",
     ]
 
     low_let_go = slicedict(LOW_SAMPLE_LET, go_param_names)
@@ -221,6 +248,7 @@ def test_make_scalrecommendation_go():
     assert "Lw" not in high_let_go
     high = PyscalFactory.create_water_oil_gas(high_let_go)
     rec = SCALrecommendation(low, base, high)
+    assert rec.type == WaterOilGas
     interpolant = rec.interpolate(-0.5)
     check_table(interpolant.gasoil.table)
     assert interpolant.wateroil is None
@@ -277,29 +305,118 @@ def test_boundary_cases():
         "foo",
         h=0.1,
     )
-    # Object reference equivalence is a little bit strict,
-    # because it would be perfectly fine if interpolate()
-    # retured copied objects. But we don't have an equivalence operator
-    # implemented.
-    assert rec.interpolate(0).wateroil == rec.base.wateroil
-    assert rec.interpolate(-1).wateroil == rec.low.wateroil
-    assert rec.interpolate(1).wateroil == rec.high.wateroil
-    assert rec.interpolate(0).gasoil == rec.base.gasoil
-    assert rec.interpolate(-1).gasoil == rec.low.gasoil
-    assert rec.interpolate(1).gasoil == rec.high.gasoil
+    assert rec.type == WaterOilGas
 
-    assert rec.interpolate(0, 1).wateroil == rec.base.wateroil
-    assert rec.interpolate(-1, 1).wateroil == rec.low.wateroil
-    assert rec.interpolate(1, 1).wateroil == rec.high.wateroil
+    wo_cols = ["sw", "krw", "krow"]  # no Pc in this test data
+    go_cols = ["sg", "krg", "krog"]
+    assert (
+        rec.interpolate(0)
+        .wateroil.table[wo_cols]
+        .equals(rec.base.wateroil.table[wo_cols])
+    )
+    assert (
+        rec.interpolate(-1)
+        .wateroil.table[wo_cols]
+        .equals(rec.low.wateroil.table[wo_cols])
+    )
+    assert (
+        rec.interpolate(1)
+        .wateroil.table[wo_cols]
+        .equals(rec.high.wateroil.table[wo_cols])
+    )
 
-    assert rec.interpolate(0, 1).gasoil == rec.high.gasoil
-    assert rec.interpolate(-1, 1).gasoil == rec.high.gasoil
-    assert rec.interpolate(1, 1).gasoil == rec.high.gasoil
+    assert (
+        rec.interpolate(0).gasoil.table[go_cols].equals(rec.base.gasoil.table[go_cols])
+    )
+    assert (
+        rec.interpolate(-1).gasoil.table[go_cols].equals(rec.low.gasoil.table[go_cols])
+    )
+    assert (
+        rec.interpolate(1).gasoil.table[go_cols].equals(rec.high.gasoil.table[go_cols])
+    )
 
-    assert rec.interpolate(0, 0).gasoil == rec.base.gasoil
-    assert rec.interpolate(-1, 0).gasoil == rec.base.gasoil
-    assert rec.interpolate(1, 0).gasoil == rec.base.gasoil
+    assert (
+        rec.interpolate(0, 1)
+        .wateroil.table[wo_cols]
+        .equals(rec.base.wateroil.table[wo_cols])
+    )
+    assert (
+        rec.interpolate(-1, 1)
+        .wateroil.table[wo_cols]
+        .equals(rec.low.wateroil.table[wo_cols])
+    )
+    assert (
+        rec.interpolate(1, 1)
+        .wateroil.table[wo_cols]
+        .equals(rec.high.wateroil.table[wo_cols])
+    )
 
-    assert rec.interpolate(0, -1).gasoil == rec.low.gasoil
-    assert rec.interpolate(-1, -1).gasoil == rec.low.gasoil
-    assert rec.interpolate(1, -1).gasoil == rec.low.gasoil
+    assert (
+        rec.interpolate(0, 1)
+        .gasoil.table[go_cols]
+        .equals(rec.high.gasoil.table[go_cols])
+    )
+    assert (
+        rec.interpolate(-1, 1)
+        .gasoil.table[go_cols]
+        .equals(rec.high.gasoil.table[go_cols])
+    )
+    assert (
+        rec.interpolate(1, 1)
+        .gasoil.table[go_cols]
+        .equals(rec.high.gasoil.table[go_cols])
+    )
+
+    assert (
+        rec.interpolate(0, 0)
+        .gasoil.table[go_cols]
+        .equals(rec.base.gasoil.table[go_cols])
+    )
+    assert (
+        rec.interpolate(-1, 0)
+        .gasoil.table[go_cols]
+        .equals(rec.base.gasoil.table[go_cols])
+    )
+    assert (
+        rec.interpolate(1, 0)
+        .gasoil.table[go_cols]
+        .equals(rec.base.gasoil.table[go_cols])
+    )
+
+    assert (
+        rec.interpolate(0, -1)
+        .gasoil.table[go_cols]
+        .equals(rec.low.gasoil.table[go_cols])
+    )
+    assert (
+        rec.interpolate(-1, -1)
+        .gasoil.table[go_cols]
+        .equals(rec.low.gasoil.table[go_cols])
+    )
+    assert (
+        rec.interpolate(1, -1)
+        .gasoil.table[go_cols]
+        .equals(rec.low.gasoil.table[go_cols])
+    )
+
+
+def test_gaswater_scal():
+    """Test list of gas-water objects in scal recommendation"""
+    dframe = pd.DataFrame(
+        columns=["SATNUM", "CASE", "NW", "NG", "TAG"],
+        data=[
+            [1, "pess", 2, 2, "thetag"],
+            [1, "base", 3, 3, "thetag"],
+            [1, "opt", 4, 4, "thetag"],
+        ],
+    )
+    rec_list = PyscalFactory.create_scal_recommendation_list(
+        PyscalFactory.load_relperm_df(dframe), h=0.1
+    )
+    assert rec_list.pyscaltype == SCALrecommendation
+    assert rec_list[1].type == GasWater
+    low_list = rec_list.interpolate(-1)
+    str_fam2 = low_list.dump_family_2()
+    assert "SCAL recommendation interpolation to -1" in str_fam2
+    assert "SGFN" in str_fam2
+    assert "SWFN" in str_fam2
