@@ -8,7 +8,7 @@ import numpy as np
 
 import pytest
 
-from hypothesis import given
+from hypothesis import given, settings
 import hypothesis.strategies as st
 
 from pyscal import WaterOil
@@ -45,8 +45,8 @@ def test_simple_j():
     swof = wateroil.SWOF()
     assert isinstance(swof, str)
     assert swof
-    assert sat_table_str_ok(swof)
-    assert sat_table_str_ok(wateroil.SWFN())
+    sat_table_str_ok(swof)
+    sat_table_str_ok(wateroil.SWFN())
 
 
 def test_simple_j_petro():
@@ -74,10 +74,11 @@ def test_simple_j_petro():
     swof = wateroil.SWOF()
     assert isinstance(swof, str)
     assert swof
-    assert sat_table_str_ok(swof)
-    assert sat_table_str_ok(wateroil.SWFN())
+    sat_table_str_ok(swof)
+    sat_table_str_ok(wateroil.SWFN())
 
 
+@settings(deadline=500)
 @given(
     st.floats(min_value=0.001, max_value=1000000),
     st.floats(min_value=-0.9 * MAX_EXPONENT, max_value=-0.001),
@@ -120,6 +121,7 @@ def test_normalized_j():
     float_df_checker(wateroil.table, "sw", 1.0, "pc", 0.02040 * bar_to_atm)
 
 
+@settings(deadline=500)
 @given(
     st.floats(min_value=0, max_value=0.1),  # swirr
     st.floats(min_value=0.01, max_value=0.1),  # swl - swirr
@@ -146,7 +148,7 @@ def test_norm_j_pc_random(swirr, swl, a_pc, b_pc, poro, perm, sigma_costau):
     check_table(wateroil.table)
     wateroil.add_corey_water()
     wateroil.add_corey_oil()
-    assert sat_table_str_ok(wateroil.SWOF())
+    sat_table_str_ok(wateroil.SWOF())
 
 
 def test_let_pc_pd():
@@ -167,14 +169,11 @@ def test_let_pc_pd():
     wateroil.add_LET_pc_pd(Lp=10, Ep=10, Tp=10, Lt=10, Et=10, Tt=10, Pcmax=5, Pct=2)
     assert np.isclose(wateroil.table["pc"].max(), 5)
     assert np.isclose(wateroil.table["pc"].min(), 0)
-    # On plot: hard-to-see kink at Pc=2. Linear curve from sw=0.6 to 1 due to sorw.
-    assert (
-        len(wateroil.table[(wateroil.table["sw"] >= 0.6) & (wateroil.table["sw"] <= 1)])
-        == 2
-    )
+    # On plot: hard-to-see kink at Pc=2. .
+    # wateroil.plotpc()
     wateroil.add_corey_water()
     wateroil.add_corey_oil()
-    assert sat_table_str_ok(wateroil.SWOF())
+    sat_table_str_ok(wateroil.SWOF())
 
 
 def test_let_pc_imb():
@@ -197,6 +196,4 @@ def test_let_pc_imb():
     assert np.isclose(wateroil.table["pc"].min(), 1)
     wateroil.add_corey_water()
     wateroil.add_corey_oil()
-    print(wateroil.SWOF())
-
-    assert sat_table_str_ok(wateroil.SWOF())
+    sat_table_str_ok(wateroil.SWOF())
